====================================
Functions for iterating over results
====================================

.. automodule:: abed.results.walk
    :members:
    :undoc-members:
    :show-inheritance:
